@@ -18,7 +18,7 @@ class Processor(object):
             self.event = request["headers"]["X-GitHub-Event"]
             self.branch = request["payload"]["ref"].split("/")[-1]
         except Exception, ex:
-            print "ERROR:", ex
+            print "ERROR:", "processor constructor", ex
             self.application.ioloop.add_timeout(self.application.interval, self.application.next)
         else:
             self.tasks = ["git checkout %s" % self.branch, "git pull origin %s" % self.branch, self.read_config]
@@ -32,8 +32,8 @@ class Processor(object):
         try:
             tasks = config[self.branch][self.event]
             assert isinstance(tasks, list)
-        except (KeyError, AssertionError):
-            pass
+        except (KeyError, AssertionError), ex:
+            print "ERROR:", "read_config", ex
         else:
             self.tasks.extend(tasks)
 
@@ -79,7 +79,9 @@ class Application(tornado.web.Application):
             request = self.queue.pop(0)
         except IndexError:
             self.current = None
+            print "No work"
         else:
+            print "New task"
             self.current = Processor(self, request)
 
 
@@ -90,7 +92,8 @@ class Handler(tornado.web.RequestHandler):
                 "headers": self.request.headers,
                 "payload": json.loads(self.request.body)
             }
-        except ValueError:
-            raise tornado.web.HTTPError(404)
+        except ValueError, ex:
+            print "ERROR:", ex
+            raise tornado.web.HTTPError(400)
         else:
             self.application.queue.append(request)
\ No newline at end of file
